@@ -1219,6 +1219,120 @@ def generate_time(date, format='%Y-%m-%d %H:%M:%S'):
     return round(date.timestamp() * 1000)
 
 
+##
+# @desc Creates a time in milliseconds from given parameters
+#
+# @param seconds -- The seconds from or before the current time
+# @param minutes -- The minutes from or before the current time
+# @param hours   -- The hours from or before the current time
+# @param days    -- The days from or before the current time
+# @param weeks   -- The weeks from or before the current time
+# @param months  -- The months from or before the current time
+# @param years   -- The years from or before the current time
+# 
+# @retun int|bool
+##
+def create_time(seconds:int=0, minutes:int=0, hours:int=0, days:int=0, weeks:int=0, months:int=0, years:int=0):
+    # Find today datetime
+    today = datetime.now()
+
+    # Check months & year
+    if months or years:
+        # Split date
+        split_date = str(today).split('-')
+
+        # Find year
+        year  = int(split_date[0]) + years
+
+        # Find month
+        month = int(split_date[1]) + months
+
+        # Update year
+        year += month // 12
+
+        # Update month
+        month = month % 12
+
+        # Check final month
+        if month == 0:
+            # Update month and year
+            month = 12
+            year -= 1
+
+        # Check year
+        if year not in range(1970, 2038):
+            print('Warning! create_time() method can only create date from 1970, 2038!')
+            return False
+
+        # Stringify month
+        if month >= 10: month = str(month)
+        else:           month = '0' + str(month)
+
+        # Stringify year
+        year = str(year)
+
+        # Generate the new date
+        new_date = year + '-' + month + '-' + split_date[2]
+
+        # Correct time range
+        try:
+            # Update today
+            today = datetime.strptime(new_date, '%Y-%m-%d %H:%M:%S.%f')
+
+        # Wrong time range
+        except:
+            split_day = split_date[2].split(' ')
+
+            # Go to the first day of the next month
+            # Update day
+            day = 1
+
+            # Refine month & year formats
+            year  = int(year)
+            month = int(month)
+
+            # Check month
+            if month == 12:
+                month = 1
+                year += 1
+            else:
+                month += 1
+
+            # Stringify day
+            day = str(day)
+
+            # Stringify month
+            if month >= 10: month = str(month)
+            else:           month = '0' + str(month)
+
+            # Stringify year
+            year = str(year)
+
+            # Generate the new date
+            new_date = year + '-' + month + '-' + day + ' ' + split_day[1]
+
+            # Update today
+            today = datetime.strptime(new_date, '%Y-%m-%d %H:%M:%S.%f')
+
+    # Generate time delta
+    delta = timedelta(
+        seconds = seconds * -1,
+        minutes = minutes * -1,
+        hours = hours * -1,
+        days = days * -1,
+        weeks = weeks * -1
+    )
+
+    # Generate the date without months & years
+    final_date = str(today - delta)
+
+    # Convert the date into milliseconds
+    result = generate_time(date=final_date, format='%Y-%m-%d %H:%M:%S.%f')
+
+    # Return the result
+    return result
+
+
 ##
 # @desc Generates the current date
 # 
@@ -1242,6 +1356,24 @@ def generate_date(time_ms: int, format: str = '%Y-%m-%d %H:%M:%S'):
     return datetime.fromtimestamp(round(time_ms / 1000.0)).strftime(format)
 
 
+##
+# @desc Creates datetime from given parameters
+# 
+# @param seconds -- The seconds from or before the current time
+# @param minutes -- The minutes from or before the current time
+# @param hours   -- The hours from or before the current time
+# @param days    -- The days from or before the current time
+# @param weeks   -- The weeks from or before the current time
+# @param months  -- The months from or before the current time
+# @param years   -- The years from or before the current time
+# @param format  -- The date format
+#
+# @retun int|bool
+##
+def create_date(seconds:int=0, minutes:int=0, hours:int=0, days:int=0, weeks:int=0, months:int=0, years:int=0, format: str = '%Y-%m-%d %H:%M:%S'):
+    return generate_date(time_ms=create_time(seconds=seconds, minutes=minutes, hours=hours, days=days, weeks=weeks, months=months, years=years), format=format)
+
+
 ##
 # @desc Returns week number of a time (in milliseconds) or a date, starting from 1
 # 
@@ -1272,6 +1404,31 @@ def week_number(time, first_day='Sunday', format='%Y-%m-%d'):
     return int(week)
 
 
+##
+# @desc Returns seconds difference between two times (in milliseconds) or dates
+# 
+# @param time_one: int|str -- The first time (or date)
+# @param time_two: int|str -- The second time (or date)
+# @param format: str       -- The date format if times are date
+#
+# @retun int
+##
+def delta_seconds(time_one, time_two, format='%Y-%m-%d %H:%M:%S'):
+    # Generates dates
+    if isinstance(time_one, int):
+        date_one = datetime.strptime(generate_date(time_one, format), format)
+        date_two = datetime.strptime(generate_date(time_two, format), format)
+    else:
+        date_one = datetime.strptime(time_one, format)
+        date_two = datetime.strptime(time_two, format)
+
+    # Find dates delta
+    delta = date_one - date_two
+
+    # Return delta seconds
+    return round(delta.total_seconds())
+
+
 ##
 # @desc Returns days difference between two times (in milliseconds) or dates
 # 
